==> asksuite-core-1.0.28.tgz: package/omnibees.crawler.js <==
const cheerio = require('cheerio');
const HeadlessChrome = require('simple-headless-chrome-asksuite')
require('datejs')

var PromiseBlue = require('bluebird');
const browser = new HeadlessChrome({
    headless: true // If you turn this off, you can actually see the browser navigate with your instructions
    // see above if using remote interface
})

function replace(str) {
    return str.replace(new RegExp('\t', 'g'), "")
}


function getPosition(string, subString, index) {
    return string.split(subString, index).join(subString).length;
}

function getNumber(str) {
    var regex = /\d+/g;
    var matches = str.match(regex);


    return matches[0];
}

function parse(parseData) {

    let day = parseData.substring(0, 2);
    let month = parseData.substring(2, 4);
    let year = parseData.substring(4, 8);

    return new Date(year, month, day)
}

async function test(browser, url, linkDetails){
    // await browser.init()
    let descriptionTab = await browser.newTab({privateTab: false})
    await descriptionTab.goTo(url+linkDetails, {timeout: 20000});

    await descriptionTab.waitForSelectorToLoad('body')


    let newHtmlTag = await descriptionTab.evaluate(function (selector) {
        const selectorHtml = document.querySelector(selector)
        return selectorHtml.innerHTML
    }, 'body'); // returns innerHTML of first matching selector for class "main"

    let x = cheerio.load(newHtmlTag.result.value);


    return x;
}

async function navigateWebsite(id, checkin, checkout, adultos, criancas ) {



    return new Promise(async (resolve, reject) => {
        try {
            await browser.init()

            const mainTab = await browser.newTab({privateTab: false})


            let url = "https://myreservations.omnibees.com"

            let ages = "-";
            if (criancas && parseInt(criancas) > 0){
                ages = "";
                for (let i =0; i < criancas; i++){
                    ages += "1;"
                }

                ages = ages.substring(0, ages.length-1);
            }

            let urlBuild = `${url}/default.aspx?q=3687&diff=false&CheckIn=${checkin}&CheckOut=${checkout}&Code=&group_code=&loyality_card=&NRooms=1&ad=${adultos}&ch=${criancas}&ag=${ages}`
            // await mainTab.injectRemoteScript("https://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js")


            console.log(urlBuild);

            await mainTab.goTo(urlBuild, {timeout: 20000})


            await mainTab.waitForSelectorToLoad('body')


            const htmlTag = await mainTab.evaluate(function (selector) {
                const selectorHtml = document.querySelector(selector)
                return selectorHtml.innerHTML
            }, 'body'); // returns innerHTML of first matching selector for class "main"


            // console.log(htmlTag.result.value);

            let $ = cheerio.load(htmlTag.result.value);
            let promise = null;

            let rooms = [];


            let puhs = []
            let itens = await $(".roomName").each((index, item) => {puhs.push( item)} )




                PromiseBlue.map(puhs, async (tdx) => {

                    let room = new HotelRoom();

                    tdx = $(tdx)

                    room.name = replace(tdx.find('.excerpt > h5').text());
                    room.price = replace(tdx.find('h6.bestPriceTextColor').text());

                    var date1 = parse(checkin)
                    var date2 = parse(checkout)

                    var diffDays = parseInt((date2 - date1) / (1000 * 60 * 60 * 24));
                    let tempPrice = parseFloat(room.price.replace("R$", '').replace(",", "."))

                    room.total = "R$ " + ((tempPrice * diffDays).toFixed(2)).replace(".", ",");

                    tdx.find('.slide > a > img').each((index, itemAmenite) => {
                        room.images.push(url + $(itemAmenite).attr('src'));
                    });

                    if (room.images) {
                        room.mainPhoto = room.images[0];
                    }

                    let linkDetails = replace(tdx.find('.excerpt > h5 > a ').attr('href'));
                    linkDetails = linkDetails.substring(0, getPosition(linkDetails, '&', 2))

                    let element = await test(browser, url, linkDetails);

                    room.amenites = [];
                    room.amountAdults = 0;
                    room.amountKids = 0;

                    let descriptionComplete = element('.roomDescription').text();
                    let description = descriptionComplete.replace(new RegExp("\n", 'g'), "").replace("Descrição", "").trim();
                    room.description = description;

                    let data = element('.room_amenities').find('p').text();
                    let elements = data.split(".");

                    elements.forEach(item => {
                        //remover primeira tag: "Serviços Gerais"
                        let amenities = item.substring(item.indexOf(':') + 1, item.length);

                        amenities.split(",").forEach(amenite => {
                            if (amenite && amenite.trim() != '') {
                                room.amenites.push(amenite.trim());
                            }

                        })
                    });

                    return room;
                }, {concurrency: 2}).then(async rooms => {

                    if (rooms && rooms.length > 0) {

                        console.log(rooms);

                        let obj = {
                            data: rooms,
                            url: urlBuild,
                        };

                        resolve(obj);

                    } else {


                        let msg = $('.info-message > h2').text().replace(new RegExp('\n', 'g'), '').replace("Alterar datas", "").trim()

                        let obj = {
                            message: replace(msg)
                        };


                        reject(obj);
                    }

                    await browser.close()
                })


        } catch (err) {
            console.log(err)
            browser.close()
            throw err;
        }
    })

}
//
// navigateWebsite(3687, '16022018', '17022018', 2, 1).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui")
//     console.log(error.message);
// })


class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite}

==> asksuite-core-1.0.29.tgz: package/omnibees.crawler.js <==
const cheerio = require('cheerio');
const HeadlessChrome = require('simple-headless-chrome-asksuite')
require('datejs')

var PromiseBlue = require('bluebird');
const browser = new HeadlessChrome({
    headless: true // If you turn this off, you can actually see the browser navigate with your instructions
    // see above if using remote interface
})

function replace(str) {
    return str.replace(new RegExp('\t', 'g'), "")
}


function getPosition(string, subString, index) {
    return string.split(subString, index).join(subString).length;
}

function getNumber(str) {
    var regex = /\d+/g;
    var matches = str.match(regex);


    return matches[0];
}

function parse(parseData) {

    let day = parseData.substring(0, 2);
    let month = parseData.substring(2, 4);
    let year = parseData.substring(4, 8);

    return new Date(year, month, day)
}

async function test(browser, url, linkDetails){
    // await browser.init()
    let descriptionTab = await browser.newTab({privateTab: false})
    await descriptionTab.goTo(url+linkDetails, {timeout: 20000});

    await descriptionTab.waitForSelectorToLoad('body')


    let newHtmlTag = await descriptionTab.evaluate(function (selector) {
        const selectorHtml = document.querySelector(selector)
        return selectorHtml.innerHTML
    }, 'body'); // returns innerHTML of first matching selector for class "main"

    let x = cheerio.load(newHtmlTag.result.value);


    return x;
}

async function navigateWebsite(id, checkin, checkout, adultos, criancas ) {



    return new Promise(async (resolve, reject) => {
        try {
            await browser.init()

            const mainTab = await browser.newTab({privateTab: false})


            let url = "https://myreservations.omnibees.com"

            let ages = "-";
            if (criancas && parseInt(criancas) > 0){
                ages = "";
                for (let i =0; i < criancas; i++){
                    ages += "1;"
                }

                ages = ages.substring(0, ages.length-1);
            }

            let urlBuild = `${url}/default.aspx?q=${id}&diff=false&CheckIn=${checkin}&CheckOut=${checkout}&Code=&group_code=&loyality_card=&NRooms=1&ad=${adultos}&ch=${criancas}&ag=${ages}`
            // await mainTab.injectRemoteScript("https://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js")


            console.log(urlBuild);

            await mainTab.goTo(urlBuild, {timeout: 20000})


            await mainTab.waitForSelectorToLoad('body')


            const htmlTag = await mainTab.evaluate(function (selector) {
                const selectorHtml = document.querySelector(selector)
                return selectorHtml.innerHTML
            }, 'body'); // returns innerHTML of first matching selector for class "main"


            // console.log(htmlTag.result.value);

            let $ = cheerio.load(htmlTag.result.value);
            let promise = null;

            let rooms = [];


            let puhs = []
            let itens = await $(".roomName").each((index, item) => {puhs.push( item)} )




                PromiseBlue.map(puhs, async (tdx) => {

                    let room = new HotelRoom();

                    tdx = $(tdx)

                    room.name = replace(tdx.find('.excerpt > h5').text());
                    room.price = replace(tdx.find('h6.bestPriceTextColor').text());

                    var date1 = parse(checkin)
                    var date2 = parse(checkout)

                    var diffDays = parseInt((date2 - date1) / (1000 * 60 * 60 * 24));
                    let tempPrice = parseFloat(room.price.replace("R$", '').replace(",", "."))

                    room.total = "R$ " + ((tempPrice * diffDays).toFixed(2)).replace(".", ",");

                    tdx.find('.slide > a > img').each((index, itemAmenite) => {
                        room.images.unshift(url + $(itemAmenite).attr('src'));
                    });

                    if (room.images) {
                        room.mainPhoto = room.images[0];
                    }

                    let linkDetails = replace(tdx.find('.excerpt > h5 > a ').attr('href'));
                    linkDetails = linkDetails.substring(0, getPosition(linkDetails, '&', 2))

                    let element = await test(browser, url, linkDetails);

                    room.amenites = [];
                    room.amountAdults = 0;
                    room.amountKids = 0;

                    let descriptionComplete = element('.roomDescription').text();
                    let description = descriptionComplete.replace(new RegExp("\n", 'g'), "").replace("Descrição", "").trim();
                    room.description = description;

                    let data = element('.room_amenities').find('p').text();
                    let elements = data.split(".");

                    elements.forEach(item => {
                        //remover primeira tag: "Serviços Gerais"
                        let amenities = item.substring(item.indexOf(':') + 1, item.length);

                        amenities.split(",").forEach(amenite => {
                            if (amenite && amenite.trim() != '') {
                                room.amenites.push(amenite.trim());
                            }

                        })
                    });

                    return room;
                }, {concurrency: 2}).then(async rooms => {

                    if (rooms && rooms.length > 0) {

                        console.log(rooms);

                        let obj = {
                            data: rooms,
                            url: urlBuild,
                        };

                        resolve(obj);

                    } else {


                        let msg = $('.info-message > h2').text().replace(new RegExp('\n', 'g'), '').replace("Alterar datas", "").trim()

                        let obj = {
                            message: replace(msg)
                        };


                        reject(obj);
                    }

                    await browser.close()
                })


        } catch (err) {
            console.log(err)
            browser.close()
            throw err;
        }
    })

}
//
navigateWebsite(3687, '20022018', '21022018', 2, 1).then(data => {
    console.log("sucesso")
}).catch(error => {
    console.log("caiu aqui")
    console.log(error.message);
})


class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite}
